.. episcanpy documentation master file, created by
   sphinx-quickstart on Thu Jan 17 14:08:45 2019.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. include:: ../README.rst
   :end-line: 24

Report issues and access the code on `GitHub <https://github.com/colomemaria/epiScanpy>`__.

.. include:: release_notes.rst

.. toctree::
   :maxdepth: 1
   :hidden:
   
   examples
   basic_usage
   System_Requirements
   installation
   api/index
   references
